
import { Button } from "@/components/ui/button";
import { useTranslation } from "react-i18next";
import { Link } from "react-router-dom";
import { Music, Users, Globe, Star } from "@/utils/iconImports";
import { useIsMobile } from "@/hooks/use-mobile";
import heroImage from "@/assets/hero-image.jpg";

const Hero = () => {
  const { t } = useTranslation();
  const isMobile = useIsMobile();

  return (
    <>
      {/* Hero Section - Mobile Optimized */}
      <section className="hero-section relative min-h-screen flex items-center justify-center overflow-hidden">
        {/* Mobile-Optimized Background */}
        <div className="hero-bg absolute inset-0 z-0">
          <picture>
            {/* Mobile-optimized WebP */}
            <source 
              media="(max-width: 768px)" 
              srcSet={`${heroImage}?format=webp&width=768&quality=75`}
              type="image/webp"
            />
            {/* Desktop WebP */}
            <source 
              media="(min-width: 769px)" 
              srcSet={`${heroImage}?format=webp&width=1920&quality=80`}
              type="image/webp"
            />
            {/* Fallback */}
            <img 
              src={heroImage} 
              alt="Artistas profesionales de música, danza y teatro colaborando en ArtMeeting.app" 
              className="w-full h-full object-cover" 
              fetchPriority="high"
              loading="eager"
              decoding="async"
              width={isMobile ? "768" : "1920"}
              height={isMobile ? "576" : "1080"}
            />
          </picture>
          <div className="hero-overlay absolute inset-0 bg-primary/80 backdrop-blur-sm"></div>
        </div>
        
        {/* Mobile-Optimized Hero Content */}
        <div className="hero-content relative z-10 container mx-auto px-4 py-12 md:py-20 text-center text-white">
          <div className="max-w-4xl mx-auto space-y-6 md:space-y-8">
            <div className="space-y-3 md:space-y-4">
              <h1 className="text-3xl md:text-6xl lg:text-7xl font-bold leading-tight">
                {isMobile ? (
                  <>Conecta tu talento<br />con oportunidades</>
                ) : (
                  "Conecta tu talento artístico con oportunidades reales"
                )}
              </h1>
              <p className="text-lg md:text-2xl text-white/90 max-w-2xl mx-auto leading-relaxed">
                {isMobile ? (
                  "Plataforma global para artistas profesionales en +50 países."
                ) : (
                  "La plataforma global que conecta músicos, bailarines, actores y artistas visuales con proyectos profesionales en más de 50 países."
                )}
              </p>
            </div>
            
            <div className="flex flex-col sm:flex-row gap-3 md:gap-4 justify-center items-center">
              <Link to="/auth">
                <Button variant="hero" size={isMobile ? "lg" : "xl"} className="w-full sm:w-auto min-w-[180px] md:min-w-[200px]">
                  {t('hero.joinAsArtist')}
                </Button>
              </Link>
              <Link to="/search">
                <Button variant="glass" size={isMobile ? "lg" : "xl"} className="w-full sm:w-auto min-w-[180px] md:min-w-[200px] text-zinc-50 bg-emerald-600 hover:bg-emerald-500">
                  {t('hero.findTalent')}
                </Button>
              </Link>
            </div>
            
            {/* Mobile-Optimized Stats Grid */}
            <div className={`grid ${isMobile ? 'grid-cols-2 gap-4 mt-12' : 'grid-cols-1 md:grid-cols-4 gap-8 mt-16'} text-center`}>
              <div className="space-y-1 md:space-y-2">
                <div className="flex justify-center mb-1 md:mb-2">
                  <Users className={`${isMobile ? 'w-6 h-6' : 'w-8 h-8'} text-secondary`} aria-hidden="true" />
                </div>
                <div className={`${isMobile ? 'text-2xl' : 'text-3xl'} font-bold text-secondary`}>+10K</div>
                <h3 className={`text-white/80 ${isMobile ? 'text-xs' : 'text-sm'} font-medium`}>Artistas registrados</h3>
              </div>
              <div className="space-y-1 md:space-y-2">
                <div className="flex justify-center mb-1 md:mb-2">
                  <Music className={`${isMobile ? 'w-6 h-6' : 'w-8 h-8'} text-secondary`} aria-hidden="true" />
                </div>
                <div className={`${isMobile ? 'text-2xl' : 'text-3xl'} font-bold text-secondary`}>+500</div>
                <h3 className={`text-white/80 ${isMobile ? 'text-xs' : 'text-sm'} font-medium`}>Colaboraciones activas</h3>
              </div>
              <div className="space-y-1 md:space-y-2">
                <div className="flex justify-center mb-1 md:mb-2">
                  <Globe className={`${isMobile ? 'w-6 h-6' : 'w-8 h-8'} text-secondary`} aria-hidden="true" />
                </div>
                <div className={`${isMobile ? 'text-2xl' : 'text-3xl'} font-bold text-secondary`}>50+</div>
                <h3 className={`text-white/80 ${isMobile ? 'text-xs' : 'text-sm'} font-medium`}>Países conectados</h3>
              </div>
              <div className="space-y-1 md:space-y-2">
                <div className="flex justify-center mb-1 md:mb-2">
                  <Star className={`${isMobile ? 'w-6 h-6' : 'w-8 h-8'} text-secondary`} aria-hidden="true" />
                </div>
                <div className={`${isMobile ? 'text-2xl' : 'text-3xl'} font-bold text-secondary`}>4.9</div>
                <h3 className={`text-white/80 ${isMobile ? 'text-xs' : 'text-sm'} font-medium`}>Valoración promedio</h3>
              </div>
            </div>
          </div>
        </div>
        
        {/* Mobile-Optimized Scroll indicator */}
        {!isMobile && (
          <div className="absolute bottom-8 left-1/2 transform -translate-x-1/2 animate-bounce">
            <div className="w-6 h-10 border-2 border-white/50 rounded-full flex justify-center">
              <div className="w-1 h-3 bg-white/70 rounded-full mt-2 animate-pulse"></div>
            </div>
          </div>
        )}
      </section>

      {/* Mobile-Optimized SEO Content Section */}
      <section className={`${isMobile ? 'py-8' : 'py-12'} bg-background`}>
        <div className="container mx-auto px-4">
          <div className="max-w-4xl mx-auto">
            <div className={`text-center ${isMobile ? 'mb-6' : 'mb-8'}`}>
              <h2 className={`${isMobile ? 'text-2xl' : 'text-3xl md:text-4xl'} font-bold text-foreground mb-4`}>
                {isMobile ? "Revolucionamos el arte" : "La plataforma que revoluciona la industria artística"}
              </h2>
            </div>
            
            <div className={`${isMobile ? 'space-y-3 text-sm' : 'space-y-4'} text-muted-foreground leading-relaxed`}>
              <p>
                <strong>ArtMeeting.app</strong> conecta más de 10,000 músicos, bailarines, actores y artistas visuales con proyectos profesionales reales en más de 50 países.
              </p>
              
              {!isMobile && (
                <>
                  <p>
                    Con perfiles verificados, búsquedas avanzadas y comunicación segura, el 95% de nuestros usuarios logra colaboraciones exitosas en proyectos de renombre internacional.
                  </p>
                  
                  <p>
                    <strong>La seguridad y profesionalidad</strong> son fundamentales: todos los perfiles pasan verificación, ofrecemos comunicación encriptada y soporte especializado 24/7.
                  </p>
                </>
              )}
            </div>
          </div>
        </div>
      </section>
    </>
  );
};

export default Hero;
